@@ -96,6 +96,7 @@ initial_tab_new (char *profile /* adopts */)
 
   it->profile = profile;
   it->exec_argv = NULL;
+  it->title = NULL;
   it->working_dir = NULL;
   it->zoom = 1.0;
   it->zoom_set = FALSE;
@@ -109,6 +110,7 @@ initial_tab_free (InitialTab *it)
 {
   g_free (it->profile);
   g_strfreev (it->exec_argv);
+  g_free (it->title);
   g_free (it->working_dir);
   g_slice_free (InitialTab, it);
 }
@@ -213,6 +215,15 @@ add_new_window (TerminalOptions *options,
 }
 
 /* handle deprecated command line options */
+
+static void
+deprecated_option_warning (const gchar *option_name)
+{
+  g_printerr (_("Option \"%s\" is deprecated and might be removed in a later version of gnome-terminal."),
+              option_name);
+  g_printerr ("\n");
+}
+
 static gboolean
 unsupported_option_callback (const gchar *option_name,
                              const gchar *value,
@@ -319,7 +330,16 @@ option_profile_cb (const gchar *option_name,
   profile = terminal_profiles_list_dup_uuid_or_name (terminal_options_ensure_profiles_list (options),
                                                      value, error);
   if (profile == NULL)
-    return FALSE;
+  {
+      g_printerr ("Profile '%s' specified but not found. Attempting to fall back "
+                  "to the default profile.\n", value);
+      g_clear_error (error);
+      profile = terminal_profiles_list_dup_uuid_or_name (terminal_options_ensure_profiles_list (options),
+                                                         NULL, error);
+  }
+
+  if (profile == NULL)
+      return FALSE;
 
   if (options->initial_windows)
     {
@@ -379,6 +399,16 @@ option_window_callback (const gchar *option_name,
 
   profile = terminal_profiles_list_dup_uuid_or_name (terminal_options_ensure_profiles_list (options),
                                                      value, error);
+
+  if (value && profile == NULL)
+  {
+      g_printerr ("Profile '%s' specified but not found. Attempting to fall back "
+                  "to the default profile.\n", value);
+      g_clear_error (error);
+      profile = terminal_profiles_list_dup_uuid_or_name (terminal_options_ensure_profiles_list (options),
+                                                         NULL, error);
+  }
+
   if (profile == NULL)
     return FALSE;
 
@@ -553,6 +583,10 @@ option_geometry_callback (const gchar *option_name,
 {
   TerminalOptions *options = data;
 
+  /* See https://bugzilla.gnome.org/show_bug.cgi?id=760944 */
+  if (gtk_check_version (3, 19, 5) == NULL)
+    return unsupported_option_callback (option_name, value, data, error);
+
   if (options->initial_windows)
     {
       InitialWindow *iw;
@@ -593,6 +627,32 @@ option_load_config_cb (const gchar *option_name,
   return result;
 }
 
+static gboolean
+option_title_callback (const gchar *option_name,
+                       const gchar *value,
+                       gpointer     data,
+                       GError     **error)
+{
+  TerminalOptions *options = data;
+
+  deprecated_option_warning (option_name);
+
+  if (options->initial_windows)
+    {
+      InitialTab *it = ensure_top_tab (options);
+
+      g_free (it->title);
+      it->title = g_strdup (value);
+    }
+  else
+    {
+      g_free (options->default_title);
+      options->default_title = g_strdup (value);
+    }
+
+  return TRUE;
+}
+
 static gboolean
 option_working_directory_callback (const gchar *option_name,
                                    const gchar *value,
@@ -763,6 +823,7 @@ terminal_options_parse (const char *working_directory,
   options->initial_windows = NULL;
   options->default_role = NULL;
   options->default_geometry = NULL;
+  options->default_title = NULL;
   options->zoom = 1.0;
   options->zoom_set = FALSE;
 
@@ -865,6 +926,7 @@ terminal_options_merge_config (TerminalOptions *options,
   for (i = 0; groups[i]; ++i)
     {
       const char *window_group = groups[i];
+      char *active_terminal;
       char **tab_groups;
       InitialWindow *iw;
       guint j;
@@ -877,6 +939,7 @@ terminal_options_merge_config (TerminalOptions *options,
       initial_windows = g_list_append (initial_windows, iw);
       apply_defaults (options, iw);
 
+      active_terminal = g_key_file_get_string (key_file, window_group, TERMINAL_CONFIG_WINDOW_PROP_ACTIVE_TAB, NULL);
       iw->role = g_key_file_get_string (key_file, window_group, TERMINAL_CONFIG_WINDOW_PROP_ROLE, NULL);
       iw->geometry = g_key_file_get_string (key_file, window_group, TERMINAL_CONFIG_WINDOW_PROP_GEOMETRY, NULL);
       iw->start_fullscreen = g_key_file_get_boolean (key_file, window_group, TERMINAL_CONFIG_WINDOW_PROP_FULLSCREEN, NULL);
@@ -898,9 +961,13 @@ terminal_options_merge_config (TerminalOptions *options,
 
           iw->tabs = g_list_append (iw->tabs, it);
 
+          if (g_strcmp0 (active_terminal, tab_group) == 0)
+            it->active = TRUE;
+
 /*          it->width = g_key_file_get_integer (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_WIDTH, NULL);
           it->height = g_key_file_get_integer (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_HEIGHT, NULL);*/
           it->working_dir = terminal_util_key_file_get_string_unescape (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_WORKING_DIRECTORY, NULL);
+          it->title = g_key_file_get_string (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_TITLE, NULL);
 
           if (g_key_file_has_key (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_COMMAND, NULL) &&
               !(it->exec_argv = terminal_util_key_file_get_argv (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_COMMAND, NULL, error)))
@@ -910,6 +977,7 @@ terminal_options_merge_config (TerminalOptions *options,
             }
         }
 
+      g_free (active_terminal);
       g_strfreev (tab_groups);
 
       if (have_error)
@@ -957,6 +1025,7 @@ terminal_options_free (TerminalOptions *options)
   g_free (options->default_role);
   g_free (options->default_geometry);
   g_free (options->default_working_dir);
+  g_free (options->default_title);
   g_free (options->default_profile);
 
   g_strfreev (options->exec_argv);
@@ -1129,8 +1198,9 @@ get_goption_context (TerminalOptions *options)
       't',
       G_OPTION_FLAG_HIDDEN,
       G_OPTION_ARG_CALLBACK,
-      unsupported_option_callback,
-      NULL, NULL
+      option_title_callback,
+      N_("Set the initial terminal title"),
+      N_("TITLE")
     },
     {
       "working-directory",
